package com.ruoyi.interfaces.service.impl;

import java.util.List;

import com.ruoyi.common.utils.uuid.IdUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.interfaces.mapper.MdDataSetMapper;
import com.ruoyi.interfaces.domain.MdDataSet;
import com.ruoyi.interfaces.service.IMdDataSetService;

/**
 * 数据集Service业务层处理
 * 
 * @author 朱得糠
 * @date 2025-07-30
 */
@Service
public class MdDataSetServiceImpl implements IMdDataSetService 
{
    @Autowired
    private MdDataSetMapper mdDataSetMapper;

    /**
     * 查询数据集
     * 
     * @param dsCode 数据集主键
     * @return 数据集
     */
    @Override
    public MdDataSet selectMdDataSetByDsCode(String dsCode)
    {
        return mdDataSetMapper.selectMdDataSetByDsCode(dsCode);
    }

    /**
     * 查询数据集列表
     * 
     * @param mdDataSet 数据集
     * @return 数据集
     */
    @Override
    public List<MdDataSet> selectMdDataSetList(MdDataSet mdDataSet)
    {
        return mdDataSetMapper.selectMdDataSetList(mdDataSet);
    }

    /**
     * 新增数据集
     * 
     * @param mdDataSet 数据集
     * @return 结果
     */
    @Override
    public int insertMdDataSet(MdDataSet mdDataSet)
    {
        mdDataSet.setDcCode(IdUtils.fastUUID());
        return mdDataSetMapper.insertMdDataSet(mdDataSet);
    }

    /**
     * 修改数据集
     * 
     * @param mdDataSet 数据集
     * @return 结果
     */
    @Override
    public int updateMdDataSet(MdDataSet mdDataSet)
    {
        return mdDataSetMapper.updateMdDataSet(mdDataSet);
    }

    /**
     * 批量删除数据集
     * 
     * @param dsCodes 需要删除的数据集主键
     * @return 结果
     */
    @Override
    public int deleteMdDataSetByDsCodes(String[] dsCodes)
    {
        return mdDataSetMapper.deleteMdDataSetByDsCodes(dsCodes);
    }

    /**
     * 删除数据集信息
     * 
     * @param dsCode 数据集主键
     * @return 结果
     */
    @Override
    public int deleteMdDataSetByDsCode(String dsCode)
    {
        return mdDataSetMapper.deleteMdDataSetByDsCode(dsCode);
    }
}
